@@ -51,6 +51,7 @@ done
 awk '{if(NF==6){print $1"\t"($2-2000)"\t"($3+2000)"\t"$4"\t"($5-2000)"\t"($6+2000)}}' $userpath/tmp3/target_comb.tmp > $userpath/tmp3/target_comb_final.tmp
 sort -k1,1 -k2,2n -k3,3n -k4,4 -k5,5n -k6,6n $userpath/tmp3/target_comb_final.tmp > $userpath/tmp3/target_comb_final_sort.tmp 
 targetFile=$userpath/tmp3/target_comb_final_sort.tmp
+cp $userpath/tmp3/target_comb_final_sort.tmp $userpath/log/target_comb_final_sort.tmp
 
 for filename in $annoFile
 do
@@ -68,5 +69,6 @@ echo "----------------------------Homer annotates done!-------------------------
 rm -f $userpath/tmp3/*.tmp
 
 echo "----------------------------Merging features!-----------------------------"
-Rscript $basepath/Rscript/MergeFeature_complete.R  $1  $userpath/tmp3  $model $userpath/feature_out.txt
+Rscript $basepath/Rscript/MergeFeature_complete.R  $userpath/log/target_comb_final_sort.tmp $userpath/tmp3  $model $userpath/feature_out.txt
+rm -f $userpath/log/*.tmp
 
